<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AddBlock</name>
    <message>
        <location filename="../AddBlockInit.js" line="+2"/>
        <source>&amp;Add Empty Block</source>
        <translation>创建空块(&amp;A)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Add new empty block</source>
        <translation>创建一个空块</translation>
    </message>
</context>
</TS>
